@@ -18,7 +18,12 @@ class Gsearch (Plugin):
         """
             returns the command map for the plugin
         """
-        cmd_map = [('gnews',self.news), ('gweb', self.web)]
+        cmd_map = [
+            ('gnews',self.news), 
+            ('gweb', self.web),
+            ('metacritic', self.metacritic),
+            ('imdb', self.imdb),
+            ('wikipedia', self.wikipedia)]
         return cmd_map
 
     def get_help(self):
@@ -27,10 +32,18 @@ class Gsearch (Plugin):
         """
         additional = '''gnews and gweb can be also combined with lang-codes, like #de, #en, #es etc:
 gnews:hamburg #de
-gweb:xmpp #de'''
+gweb:xmpp #de
+
+IMDb search can be narrowed down with #en, #de, #es, #pt, #it or #fr
+The different wikipedia versions can be selected via #en, #de, #fr etc.'''
 
         return {
-            'commands': ['gnews:word - google news search','gweb:word - google web search'],
+            'commands': [
+                'gnews:word - google news search',
+                'gweb:word - google web search',
+                'metacritic:title - search for reviews on metacritc.com',
+                'imdb:title - search for movie on IMDb',
+                'wikipedia:thing - search on wikipedia'],
             'additional': [additional],
         }
 
@@ -56,7 +69,10 @@ gweb:xmpp #de'''
             return hits
         else:
             return None
-         
+
+    def _build_query_term(self, term):
+        return 'intitle:' + ' intitle:'.join(term.split())+' '
+
     def web(self, term):
         '''
         searches web by yahoo
@@ -114,7 +130,79 @@ gweb:xmpp #de'''
 
         title = 'Google news search for %s\n' % term
         return self.render(data=hits, title=title)        
+
+    def metacritic(self, term):
+        '''
+        searches metacritic
+        '''
+        term = term.strip()
         
+        query = 'site:metacritic.com intitle:reviews %s' % self._build_query_term(term)
+        params = {
+                'v':'1.0', 
+                'q':query.encode('utf-8').lower(),
+                'rsz':'large',
+                }
+
+        response = self._api_request('web', params)
+        hits = self._extract_hits(response)
+
+        title = 'Reviews for "%s"\n' % term
+        return self.render(data=hits, title=title)        
+        
+    def imdb(self, term):
+        '''
+        searches metacritic
+        '''
+        term = term.strip()
+
+        lang = None
+
+        if term and term.find('#')+1:
+            term, lang = term.split('#',1)
+            term = term.strip()
+
+        tld = lang if lang and lang != 'en' else 'com' 
+
+        query = 'site:imdb.%s inurl:"/title/" %s' % (tld, self._build_query_term(term))
+        params = {
+                'v':'1.0', 
+                'q':query.encode('utf-8').lower(),
+                'rsz':'large',
+                }
+       
+        response = self._api_request('web', params)
+        hits = self._extract_hits(response)
+
+        title = 'Results on IMDb for "%s"\n' % term
+        return self.render(data=hits, title=title)        
+
+    def wikipedia(self, term):
+        '''
+        searches metacritic
+        '''
+        term = term.strip()
+        lang = 'en'
+
+        if term and term.find('#')+1:
+            term, lang = term.split('#',1)
+            term = term.strip()
+
+        query = 'site:%s.wikipedia.org inurl:"/wiki/" %s' % (lang, term)
+        params = {
+                'v':'1.0', 
+                'q':query.encode('utf-8').lower(),
+                'rsz':'large',
+                }
+       
+        response = self._api_request('web', params)
+        hits = self._extract_hits(response)
+
+        title = 'Wikipedia entries for "%s"\n' % term
+        return self.render(data=hits, title=title)    
+
+
+
     def render_xmpp(self, hits, title):
         '''
         renders the result for xmpp responses
